jQuery(document).ready(function($) {
    // Initialize sortable
    $('#euc-sortable').sortable({
        handle: '.euc-url-info',
        update: function(event, ui) {
            const order = $(this).sortable('toArray', { attribute: 'data-id' });
            updateOrder(order);
        }
    });

    // Add URL
    $('#euc-add-url-form').on('submit', function(e) {
        e.preventDefault();
        const url = $('#euc-url-input').val();
        if (url) {
            addUrl(url);
        }
    });

    // Delete URL
    $(document).on('click', '.euc-delete-url', function() {
        if (confirm('Are you sure you want to delete this URL?')) {
            const id = $(this).data('id');
            deleteUrl(id);
        }
    });

    // Edit URL Modal
    $(document).on('click', '.euc-edit-url', function() {
        const id = $(this).data('id');
        const item = $(this).closest('.euc-url-item');
        
        $('#euc-edit-id').val(id);
        $('#euc-edit-title').val(item.find('h3').text());
        $('#euc-edit-description').val(item.find('.euc-description').text());
        
        $('#euc-edit-modal').show();
    });

    // Close Modal
    $('.euc-modal-close').on('click', function() {
        $('#euc-edit-modal').hide();
    });

    // Submit Edit Form
    $('#euc-edit-url-form').on('submit', function(e) {
        e.preventDefault();
        
        const data = {
            id: $('#euc-edit-id').val(),
            title: $('#euc-edit-title').val(),
            description: $('#euc-edit-description').val()
        };
        
        updateUrl(data);
    });

    // Bulk Import
    $('#euc-import-form').on('submit', function(e) {
        e.preventDefault();
        const urls = $('#euc-import-urls').val().split('\n').filter(url => url.trim());
        if (urls.length) {
            importUrls(urls);
        }
    });

    // Export URLs
    $('#euc-export-urls').on('click', function() {
        exportUrls();
    });

    // AJAX Functions
    function addUrl(url) {
        const form = $('#euc-add-url-form');
        form.addClass('euc-loading');
        
        $.ajax({
            url: ajaxurl,
            type: 'POST',
            data: {
                action: 'euc_save_url',
                nonce: eucAdmin.nonce,
                url: url
            },
            success: function(response) {
                if (response.success) {
                    location.reload();
                } else {
                    alert('Failed to add URL: ' + response.data);
                }
            },
            error: function() {
                alert('Failed to add URL. Please try again.');
            },
            complete: function() {
                form.removeClass('euc-loading');
                $('#euc-url-input').val('');
            }
        });
    }

    function deleteUrl(id) {
        const item = $(`.euc-url-item[data-id="${id}"]`);
        item.addClass('euc-loading');
        
        $.ajax({
            url: ajaxurl,
            type: 'POST',
            data: {
                action: 'euc_delete_url',
                nonce: eucAdmin.nonce,
                id: id
            },
            success: function(response) {
                if (response.success) {
                    item.slideUp(function() {
                        $(this).remove();
                    });
                } else {
                    alert('Failed to delete URL');
                }
            },
            error: function() {
                alert('Failed to delete URL. Please try again.');
                item.removeClass('euc-loading');
            }
        });
    }

    function updateUrl(data) {
        const modal = $('#euc-edit-modal');
        modal.addClass('euc-loading');
        
        $.ajax({
            url: ajaxurl,
            type: 'POST',
            data: {
                action: 'euc_update_url',
                nonce: eucAdmin.nonce,
                ...data
            },
            success: function(response) {
                if (response.success) {
                    location.reload();
                } else {
                    alert('Failed to update URL');
                }
            },
            error: function() {
                alert('Failed to update URL. Please try again.');
            },
            complete: function() {
                modal.removeClass('euc-loading');
                modal.hide();
            }
        });
    }

    function updateOrder(order) {
        $.ajax({
            url: ajaxurl,
            type: 'POST',
            data: {
                action: 'euc_reorder_urls',
                nonce: eucAdmin.nonce,
                order: order
            },
            error: function() {
                alert('Failed to update order. Please try again.');
            }
        });
    }

    function importUrls(urls) {
        const form = $('#euc-import-form');
        form.addClass('euc-loading');
        
        $.ajax({
            url: ajaxurl,
            type: 'POST',
            data: {
                action: 'euc_import_urls',
                nonce: eucAdmin.nonce,
                urls: urls.join('\n')
            },
            success: function(response) {
                if (response.success) {
                    location.reload();
                } else {
                    alert('Failed to import URLs: ' + response.data);
                }
            },
            error: function() {
                alert('Failed to import URLs. Please try again.');
            },
            complete: function() {
                form.removeClass('euc-loading');
                $('#euc-import-urls').val('');
            }
        });
    }

    function exportUrls() {
        window.location.href = ajaxurl + '?action=euc_export_urls&nonce=' + eucAdmin.nonce;
    }
});
