<?php
/**
 * Plugin Name: Elegant URL Carousel
 * Plugin URI: https://wizseller.com
 * Description: An elegant carousel plugin to showcase and manage URLs with auto-fetched metadata.
 * Version: 1.0.0
 * Author: Michael J. Hanlon
 * Author URI: https://wizseller.com
 * License: GPL v2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: elegant-url-carousel
 * Domain Path: /languages
 */

// Prevent direct file access
if (!defined('ABSPATH')) {
    exit;
}

// Define plugin constants
define('EUC_VERSION', '1.0.0');
define('EUC_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('EUC_PLUGIN_URL', plugin_dir_url(__FILE__));

// Activation hook
register_activation_hook(__FILE__, 'euc_activate');

// Deactivation hook
register_deactivation_hook(__FILE__, 'euc_deactivate');

// Uninstall hook (must be a static method)
register_uninstall_hook(__FILE__, 'euc_uninstall');

/**
 * Plugin activation function
 */
function euc_activate() {
    // Create necessary database tables
    global $wpdb;
    $charset_collate = $wpdb->get_charset_collate();
    
    $sql = "CREATE TABLE IF NOT EXISTS {$wpdb->prefix}euc_urls (
        id bigint(20) NOT NULL AUTO_INCREMENT,
        url varchar(2083) NOT NULL,
        title varchar(255),
        description text,
        favicon_path varchar(255),
        last_fetched datetime,
        order_index int DEFAULT 0,
        custom_title varchar(255),
        custom_description text,
        active tinyint(1) DEFAULT 1,
        created_at datetime DEFAULT CURRENT_TIMESTAMP,
        updated_at datetime DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
        PRIMARY KEY  (id),
        KEY url (url(191))
    ) $charset_collate;";

    require_once(ABSPATH . 'wp-admin/includes/upgrade.php');
    dbDelta($sql);

    // Set default options
    $default_options = array(
        'carousel_speed' => 3000,
        'visible_items' => 3,
        'primary_color' => '#007bff',
        'secondary_color' => '#6c757d',
        'animation_effect' => 'slide',
        'cache_duration' => 3600,
        'auto_play' => true,
        'card_layout' => 'standard'
    );
    
    add_option('euc_settings', $default_options);
}

/**
 * Plugin deactivation function
 */
function euc_deactivate() {
    // Clear scheduled events
    wp_clear_scheduled_hook('euc_daily_cleanup');
}

/**
 * Plugin uninstall function
 */
function euc_uninstall() {
    global $wpdb;
    
    // Drop custom tables
    $wpdb->query("DROP TABLE IF EXISTS {$wpdb->prefix}euc_urls");
    
    // Delete options
    delete_option('euc_settings');
    
    // Clean up uploaded favicons
    $upload_dir = wp_upload_dir();
    $favicon_dir = $upload_dir['basedir'] . '/euc-favicons';
    if (is_dir($favicon_dir)) {
        array_map('unlink', glob("$favicon_dir/*.*"));
        rmdir($favicon_dir);
    }
}

// Load required files
require_once EUC_PLUGIN_DIR . 'includes/class-euc-admin.php';
require_once EUC_PLUGIN_DIR . 'includes/class-euc-public.php';
require_once EUC_PLUGIN_DIR . 'includes/class-euc-url-handler.php';

// Initialize the plugin
function euc_init() {
    // Initialize admin
    if (is_admin()) {
        new EUC_Admin();
    }
    
    // Initialize public
    new EUC_Public();
}
add_action('plugins_loaded', 'euc_init');
