<?php
/**
 * Public functionality for Elegant URL Carousel
 */

class EUC_Public {
    /**
     * Initialize the public class
     */
    public function __construct() {
        add_action('wp_enqueue_scripts', array($this, 'enqueue_public_assets'));
        add_shortcode('url-carousel', array($this, 'render_carousel'));
    }

    /**
     * Enqueue public assets
     */
    public function enqueue_public_assets() {
        // Only enqueue if shortcode is present
        global $post;
        if (is_a($post, 'WP_Post') && has_shortcode($post->post_content, 'url-carousel')) {
            wp_enqueue_style(
                'swiper-css',
                'https://unpkg.com/swiper/swiper-bundle.min.css',
                array(),
                '8.4.7'
            );

            wp_enqueue_style(
                'euc-public-style',
                EUC_PLUGIN_URL . 'assets/css/public.css',
                array('swiper-css'),
                EUC_VERSION
            );

            wp_enqueue_script(
                'swiper-js',
                'https://unpkg.com/swiper/swiper-bundle.min.js',
                array(),
                '8.4.7',
                true
            );

            wp_enqueue_script(
                'euc-public-script',
                EUC_PLUGIN_URL . 'assets/js/public.js',
                array('jquery', 'swiper-js'),
                EUC_VERSION,
                true
            );

            // Get plugin settings
            $settings = get_option('euc_settings');
            wp_localize_script('euc-public-script', 'eucPublic', array(
                'settings' => $settings
            ));

            // Add inline styles for customization
            $this->add_custom_styles($settings);
        }
    }

    /**
     * Add custom styles based on settings
     */
    private function add_custom_styles($settings) {
        $custom_css = "
            .euc-carousel .swiper-slide {
                border-color: {$settings['primary_color']};
            }
            .euc-carousel .euc-title a {
                color: {$settings['primary_color']};
            }
            .euc-carousel .swiper-button-next,
            .euc-carousel .swiper-button-prev {
                color: {$settings['primary_color']};
            }
        ";

        wp_add_inline_style('euc-public-style', $custom_css);
    }

    /**
     * Render the carousel
     */
    public function render_carousel($atts) {
        // Get carousel items
        global $wpdb;
        $items = $wpdb->get_results(
            "SELECT * FROM {$wpdb->prefix}euc_urls 
            WHERE active = 1 
            ORDER BY order_index ASC"
        );

        if (empty($items)) {
            return '<p>' . __('No URLs found.', 'elegant-url-carousel') . '</p>';
        }

        // Get settings
        $settings = get_option('euc_settings');

        // Start output buffering
        ob_start();

        // Include template
        include EUC_PLUGIN_DIR . 'templates/carousel.php';

        // Return the buffered content
        return ob_get_clean();
    }

    /**
     * Get cached carousel HTML
     */
    private function get_cached_carousel($items, $settings) {
        $cache_key = 'euc_carousel_' . md5(serialize($items) . serialize($settings));
        $cached_html = get_transient($cache_key);

        if ($cached_html !== false) {
            return $cached_html;
        }

        // Generate carousel HTML
        ob_start();
        include EUC_PLUGIN_DIR . 'templates/carousel.php';
        $html = ob_get_clean();

        // Cache for 1 hour
        set_transient($cache_key, $html, HOUR_IN_SECONDS);

        return $html;
    }
}
