<?php
if (!defined('ABSPATH')) exit;
?>

<div class="wrap">
    <h1><?php echo esc_html(get_admin_page_title()); ?></h1>

    <div class="euc-admin-container">
        <!-- Settings Tab -->
        <div class="euc-tab-content" id="settings">
            <form method="post" action="options.php">
                <?php
                settings_fields('euc_settings');
                do_settings_sections('elegant-url-carousel');
                submit_button();
                ?>
            </form>
        </div>

        <!-- URL Management Tab -->
        <div class="euc-tab-content" id="urls">
            <div class="euc-url-form">
                <h2><?php _e('Add New URL', 'elegant-url-carousel'); ?></h2>
                <form id="euc-add-url-form">
                    <input type="url" id="euc-url-input" placeholder="<?php esc_attr_e('Enter URL', 'elegant-url-carousel'); ?>" required>
                    <button type="submit" class="button button-primary"><?php _e('Add URL', 'elegant-url-carousel'); ?></button>
                </form>
            </div>

            <div class="euc-url-list">
                <h2><?php _e('Managed URLs', 'elegant-url-carousel'); ?></h2>
                <div id="euc-urls-container">
                    <?php if (!empty($urls)) : ?>
                        <ul id="euc-sortable">
                            <?php foreach ($urls as $url) : ?>
                                <li class="euc-url-item" data-id="<?php echo esc_attr($url->id); ?>">
                                    <div class="euc-url-info">
                                        <?php if ($url->favicon_path) : ?>
                                            <img src="<?php echo esc_url($url->favicon_path); ?>" alt="favicon" class="euc-favicon">
                                        <?php endif; ?>
                                        <div class="euc-url-details">
                                            <h3><?php echo esc_html($url->title); ?></h3>
                                            <p class="euc-url"><?php echo esc_url($url->url); ?></p>
                                            <p class="euc-description"><?php echo esc_html($url->description); ?></p>
                                        </div>
                                    </div>
                                    <div class="euc-url-actions">
                                        <button class="button euc-edit-url" data-id="<?php echo esc_attr($url->id); ?>">
                                            <?php _e('Edit', 'elegant-url-carousel'); ?>
                                        </button>
                                        <button class="button euc-delete-url" data-id="<?php echo esc_attr($url->id); ?>">
                                            <?php _e('Delete', 'elegant-url-carousel'); ?>
                                        </button>
                                    </div>
                                </li>
                            <?php endforeach; ?>
                        </ul>
                    <?php else : ?>
                        <p><?php _e('No URLs added yet.', 'elegant-url-carousel'); ?></p>
                    <?php endif; ?>
                </div>
            </div>

            <!-- Bulk Import/Export -->
            <div class="euc-bulk-actions">
                <h2><?php _e('Bulk Import/Export', 'elegant-url-carousel'); ?></h2>
                <div class="euc-import">
                    <h3><?php _e('Import URLs', 'elegant-url-carousel'); ?></h3>
                    <form id="euc-import-form">
                        <textarea id="euc-import-urls" rows="5" placeholder="<?php esc_attr_e('Enter URLs (one per line)', 'elegant-url-carousel'); ?>"></textarea>
                        <button type="submit" class="button button-primary"><?php _e('Import', 'elegant-url-carousel'); ?></button>
                    </form>
                </div>
                <div class="euc-export">
                    <h3><?php _e('Export URLs', 'elegant-url-carousel'); ?></h3>
                    <button id="euc-export-urls" class="button"><?php _e('Export All URLs', 'elegant-url-carousel'); ?></button>
                </div>
            </div>
        </div>
    </div>
</div>

<!-- Edit URL Modal -->
<div id="euc-edit-modal" class="euc-modal">
    <div class="euc-modal-content">
        <span class="euc-modal-close">&times;</span>
        <h2><?php _e('Edit URL', 'elegant-url-carousel'); ?></h2>
        <form id="euc-edit-url-form">
            <input type="hidden" id="euc-edit-id">
            <div class="euc-form-group">
                <label for="euc-edit-title"><?php _e('Title', 'elegant-url-carousel'); ?></label>
                <input type="text" id="euc-edit-title">
            </div>
            <div class="euc-form-group">
                <label for="euc-edit-description"><?php _e('Description', 'elegant-url-carousel'); ?></label>
                <textarea id="euc-edit-description" rows="3"></textarea>
            </div>
            <button type="submit" class="button button-primary"><?php _e('Save Changes', 'elegant-url-carousel'); ?></button>
        </form>
    </div>
</div>
